@@ -1,5 +1,5 @@
 
-def corr_matrix(df):
+def corr_matrix(df,  figsize = (10,8)):
     import seaborn as sns
     import matplotlib.pyplot as plt
     
@@ -7,7 +7,7 @@ def corr_matrix(df):
     cMap = plt.cm.get_cmap("bwr",lut=n_colors ) 
 
     # definir el heatmap
-    plt.figure( figsize=(10, 8))
+    plt.figure( figsize=figsize)
     h_map = sns.heatmap(df.corr().values, 
                         vmin=-1., vmax=1., 
                         cmap=cMap, 
@@ -29,7 +29,7 @@ def corr_matrix(df):
     plt.show()
 
 
-def plot_boxplots(data, norm = True):
+def plot_boxplots(data, norm = True, figsize=(16, 7)):
     import matplotlib.pyplot as plt
     import pandas as pd
     import seaborn as sns
@@ -39,7 +39,7 @@ def plot_boxplots(data, norm = True):
     else:
         df = data
 
-    plt.figure( figsize=(16, 7))
+    plt.figure( figsize=figsize)
     plt.title("Boxplots")
     sns.set_style("white")
     bx_plot = sns.boxplot(data=df)
