@@ -1,6 +1,7 @@
 
 def get_stock_data(tickers, prices = False, financials = False,
-                   info = False, recommendations = False):
+                   info = False, recommendations = False,
+                   period = "max"):
     import pandas as pd
     import yfinance as yf
     
@@ -12,7 +13,7 @@ def get_stock_data(tickers, prices = False, financials = False,
         try:
             if prices == True:
                 stock = yf.Ticker(ticker)
-                stock = stock.history(period="max")
+                stock = stock.history(period=period)
                 information[ticker] = stock
             
             if financials == True:
